package readxls;
/*-**********************************************************************
 * File: InvalidCellInfo.java
 * 	(Extracted from
 *	   "$Id$")
 *
 * Abstracts:
 *  This Java source code implements "readxls" package.
 *  "readxls" package reads a excel file (extension ".xls" only),
 *  and create a hashtable contains header cell values or
 *  a list of detaile record cell values.
 *  If package find several invalid data cells. information about
 *  the invalid cells is outputed into a list.
 *  This package depends on JExcelAPI.
 *
 * Copyright (C) 2014 Maoyam Tokyo, Japan (mailto:maoyam@mail.goo.ne.jp)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *-*********************************************************************/

import readxls.control.CellDefine;
import readxls.type.CellTypeDefine;

/** 不正データ.
 * <P>
 * セルごとの必須入力、型、入力値の正当性が認められないものについての
 * 情報。
 * </P>
 *
 * @author maoyam (maoyam@mail.goo.ne.jp)
 */
public class InvalidCellInfo {

	/** 不正データ情報.
	 * <P>
	 * 不正データを見つけた行の行番号 (1～)
	 * </P>
	 */
	private int rowNo = 0;

	/** 不正データ情報.
	 * <P>
	 * 不正データを見つけた列の列番号 (1～)
	 * </P>
	 */
	private int columnNo = 0;

	/** 不正データ情報.
	 * <P>
	 * 不正データを見つけたセルの項目名称
	 * </P>
	 */
	private String name = null;

	/** 不正データ情報.
	 * <P>
	 * 不正データの確認内容に応じたメッセージ
	 * </P>
	 */
	private String messageId = null;

	/** 不正データ情報.
	 * <P>
	 * 不正データを見つけたセルの型
	 * </P>
	 */
	private CellTypeDefine cellType = null;

	/** 不正データ情報.
	 * <P>
	 * 不正データを見つけた確認内容についてのセル定義情報
	 * </P>
	 */
	private CellDefine cellDefine = null;

	/** getter/setter.
	 * @return
	 * {@link InvalidCellInfo#rowNo}
	 * を返す。
	 */
	public final int getRowNo() {
		return this.rowNo;
	}

	/** getter/setter.
	 * @param rowNo
	 * {@link InvalidCellInfo#rowNo}
	 * に設定する値 (1～)。
	 */
	public final void setRowNo(final int rowNo) {
		this.rowNo = rowNo;
	}

	/** getter/setter.
	 * @return
	 * {@link InvalidCellInfo#columnNo}
	 * を返す。
	 */
	public final int getColumnNo() {
		return this.columnNo;
	}

	/** getter/setter.
	 * @param columnNo
	 * {@link InvalidCellInfo#columnNo}
	 * に設定する値 (1～)。
	 */
	public final void setColumnNo(final int columnNo) {
		this.columnNo = columnNo;
	}

	/** getter/setter.
	 * @return
	 * {@link InvalidCellInfo#name}
	 * を返す。
	 */
	public final String getName() {
		return this.name;
	}

	/** getter/setter.
	 * @param name
	 * {@link InvalidCellInfo#name}
	 * に設定する値。
	 */
	public final void setName(final String name) {
		this.name = name;
	}

	/** getter/setter.
	 * @return
	 * {@link InvalidCellInfo#messageId}
	 * を返す。
	 */
	public final String getMessageId() {
		return this.messageId;
	}

	/** getter/setter.
	 * @param messageId
	 * {@link InvalidCellInfo#messageId}
	 * に設定する値。
	 */
	public final void setMessageId(final String messageId) {
		this.messageId = messageId;
	}

	/** getter/setter.
	 * @return
	 * {@link InvalidCellInfo#cellType}
	 * を返す。
	 */
	public final CellTypeDefine getCellType() {
		return this.cellType;
	}

	/** getter/setter.
	 * @param cellType
	 * {@link InvalidCellInfo#cellType}
	 * に設定する値。
	 */
	public final void setCellType(final CellTypeDefine cellType) {
		this.cellType = cellType;
	}

	/** getter/setter.
	 * @return
	 * セル定義情報
	 * {@link InvalidCellInfo#cellDefine}
	 * を返す。
	 */
	public final CellDefine getCellDefine() {
		return this.cellDefine;
	}

	/** getter/setter.
	 * @param cellDefine
	 * {@link InvalidCellInfo#cellDefine}
	 * に設定するセル定義情報。
	 */
	public final void setCellDefine(final CellDefine cellDefine) {
		this.cellDefine = cellDefine;
	}

	/** コンストラクタ.
	 * @param rowNo
	 * 不正データを見つけた行の行番号 (1～)
	 * @param columnNo
	 * 不正データを見つけた列の列番号 (1～)
	 * @param name
	 * 不正データを見つけたセルの項目名
	 * @param messageId
	 * 不正データの内容についてのメッセージ
	 * @param cellType
	 * 不正データを見つけたセルの型
	 * @param cellDefine
	 * 不正データと判断したセル定義情報
	 * @see CellTypeDefine
	 * @see CellDefine
	 */
	public InvalidCellInfo(final int				rowNo,
							final int				columnNo,
							final String			name,
							final String			messageId,
							final CellTypeDefine	cellType,
							final CellDefine		cellDefine) {
		this.rowNo		= rowNo;
		this.columnNo	= columnNo;
		this.name		= name;
		this.messageId	= messageId;
		this.cellType	= cellType;
		this.cellDefine	= cellDefine;
	}

}
