package readxls;
/*-**********************************************************************
 * File: ReturnCode.java
 * 	(Extracted from
 *	   "$Id$")
 *
 * Abstracts:
 *  This Java source code implements "readxls" package.
 *  "readxls" package reads a excel file (extension ".xls" only),
 *  and create a hashtable contains header cell values or
 *  a list of detaile record cell values.
 *  If package find several invalid data cells. information about
 *  the invalid cells is outputed into a list.
 *  This package depends on JExcelAPI.
 *
 * Copyright (C) 2014 Maoyam Tokyo, Japan (mailto:maoyam@mail.goo.ne.jp)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *-*********************************************************************/

/** 列挙型.
 * JExcelApi を利用するためのユーティリティの戻り値を列挙型で定義している。
 *
 * @author maoyam (maoyam@mail.goo.ne.jp)
 */
public enum ReturnCode {

	/** 定数.
	 * 正常に処理できた (=0)。
	 */
	NORMAL(0)
	,
	/** 定数.
	 * 引数が不正である (=1)。
	 */
	ILLEGAL_ARGUMENT(1)
	,
	/** 定数.
	 * Excel ファイル形式ではない (=2)。
	 */
	NOT_EXL_FILE(2)
	,
	/** 定数.
	 * 指定されたシートが存在しない (=3)
	 */
	NOT_FOUND_SHEET(3)
	,
	/** 定数.
	 * 値が不正なセルがある (=4)。
	 */
	FOUND_INVALID_CELLS(4)
	,
	/** 定数.
	 * ユーザが定義した {@link InvalidCellInfoCollector}
	 * が {@link ReadXlsException} を投げる場合のエラーコード
	 * (={@link Integer#MAX_VALUE})。
	 */
	EXTRA_DEFINED_ERROR(Integer.MAX_VALUE)
	,
	/** 定数.
	 * Java でサポートしていない charset
	 * (={@link Integer#MIN_VALUE})。
	 */
	UNSUPPORTED_CHARSET(Integer.MIN_VALUE);

	/** フィールド.
	 * 列挙型の値を保持する。
	 */
	private int returnCode;

	/** 列挙方のコンストラクタ.
	 * @param returnCode 列挙型の値。
	 */
	private ReturnCode(final int returnCode) {
		this.returnCode = returnCode;
	}

	/** 機能.
	 * 列挙型の値を取得する。
	 * @return 列挙型の値。
	 */
	public final int getReturnCode() {
		return this.returnCode;
	}

}
