package readxls.control;
/*-**********************************************************************
 * File: Breaker.java
 * 	(Extracted from
 *	   "$Id$")
 *
 * Abstracts:
 *  This Java source code implements "readxls" package.
 *  "readxls" package reads a excel file (extension ".xls" only),
 *  and create a hashtable contains header cell values or
 *  a list of detaile record cell values.
 *  If package find several invalid data cells. information about
 *  the invalid cells is outputed into a list.
 *  This package depends on JExcelAPI.
 *
 * Copyright (C) 2014 Maoyam Tokyo, Japan (mailto:maoyam@mail.goo.ne.jp)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *-*********************************************************************/

import readxls.XlsHandler;

/** 行・列の読み込み終了位置制御.
 * <P>
 * シートから明細情報を読み込む際の、行と列の読み込み終了位置を求める
 * 制御機能を実装するインタフェース。
 * </P>
 *
 * @author maoyam (maoyam@mail.goo.ne.jp)
 */
public interface Breaker {

	/** インタフェース実装クラスの機能.
	 * <P>
	 * 行・列の読み込み終了位置を求めるための制御パラメータが
	 * 正当なものであることを確認する。
	 * </P>
	 * @return
	 * 制御パラメータが正当なものであれば true
	 * を、そうでなければ true を返す。
	 */
	boolean isValid();

	/** インタフェース実装クラスの機能.
	 * <P>
	 * 明細情報を読み込む行の終了位置を行番号で返す。
	 * </P>
	 * @param xlsHandler
	 * Excel ファイルを読み込むための依存ライブラリ呼び出し手順の実装
	 * @param firstDetailRowNo
	 * 明細情報を構成する最初の行に当たるシートの読み込み行の番号 (1～)
	 * @param readableRowNum
	 * シートにデータ入力されているセルがある最後の行の番号 (1～)
	 * @return
	 * 明細情報を読み込む行の終了位置の行番号 (1～)
	 */
	int getBreakRowNo(XlsHandler	xlsHandler,
						int			firstDetailRowNo,
						int			readableRowNum);

	/** インタフェース実装クラスの機能.
	 * <P>
	 * 明細情報を読み込む列の終了位置を列番号で返す。
	 * </P>
	 * @param xlsHandler
	 * Excel ファイルを読み込むための依存ライブラリ呼び出し手順の実装
	 * @param rno
	 * 読み込む行の行番号 (1～)
	 * @param breakRowNo
	 * 読み込みを終了する行の行番号 (1～)
	 * @return
	 * 明細情報を読み込む列の終了位置の列番号 (1～)。
	 * <BR>
	 * 読み込む列がひとつもない場合はゼロを返す。
	 */
	int getBreakColumnNo(XlsHandler xlsHandler, int rno, int breakRowNo);

}
