package readxls.type;
/*-**********************************************************************
 * File: CellTypeDefine.java
 * 	(Extracted from
 *	   "$Id$")
 *
 * Abstracts:
 *  This Java source code implements "readxls" package.
 *  "readxls" package reads a excel file (extension ".xls" only),
 *  and create a hashtable contains header cell values or
 *  a list of detaile record cell values.
 *  If package find several invalid data cells. information about
 *  the invalid cells is outputed into a list.
 *  This package depends on JExcelAPI.
 *
 * Copyright (C) 2014 Maoyam Tokyo, Japan (mailto:maoyam@mail.goo.ne.jp)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *-*********************************************************************/

/** 読み込みセルの項目定義.
 * <P>
 * セルの型の種別を定義する {@link Enum}
 * </P>
 * <P>
 * 定義されているセルの型は、フィラーを指定する空セル、論理値型、日付型、
 * 数値型、文字列型。
 * </P>
 *
 * @author maoyam (maoyam@mail.goo.ne.jp)
 */
public enum CellTypeDefine {

	/** 空セル. */
	EMPTY(0)
	,
	/** 論理値型セル. */
	BOOLEAN(1)
	,
	/** 日付型セル. */
	DATE(2)
	,
	/** 数値型セル. */
	NUMBER(3)
	,
	/** 文字列型セル. */
	STRING(4);

	/** 列挙型の値を保持する. */
	private int type;

	/** 列挙方のコンストラクタ.
	 * @param type 列挙型の値。
	 */
	private CellTypeDefine(final int type) {
		this.type = type;
	}

	/** 列挙型の値を取得する.
	 * @return 列挙型の値。
	 */
	public final int getType() {
		return this.type;
	}

}
